<?php

namespace App\Http\Controllers\API;

use App\Http\Requests\API\CreateProductDailyWinTimeAPIRequest;
use App\Http\Requests\API\UpdateProductDailyWinTimeAPIRequest;
use App\Models\ProductDailyWinTime;
use App\Repositories\ProductDailyWinTimeRepository;
use Illuminate\Http\Request;
use App\Http\Controllers\AppBaseController;
use Response;

/**
 * Class ProductDailyWinTimeController
 * @package App\Http\Controllers\API
 */

class ProductDailyWinTimeAPIController extends AppBaseController
{
    /** @var  ProductDailyWinTimeRepository */
    private $productDailyWinTimeRepository;

    public function __construct(ProductDailyWinTimeRepository $productDailyWinTimeRepo)
    {
        $this->productDailyWinTimeRepository = $productDailyWinTimeRepo;
    }

    /**
     * Display a listing of the ProductDailyWinTime.
     * GET|HEAD /productDailyWinTimes
     *
     * @param Request $request
     * @return Response
     */
    public function index(Request $request)
    {
        $productDailyWinTimes = $this->productDailyWinTimeRepository->all(
            $request->except(['skip', 'limit']),
            $request->get('skip'),
            $request->get('limit')
        );

        return $this->sendResponse($productDailyWinTimes->toArray(), 'Product Daily Win Times retrieved successfully');
    }

    /**
     * Store a newly created ProductDailyWinTime in storage.
     * POST /productDailyWinTimes
     *
     * @param CreateProductDailyWinTimeAPIRequest $request
     *
     * @return Response
     */
    public function store(CreateProductDailyWinTimeAPIRequest $request)
    {
        $input = $request->all();

        $productDailyWinTime = $this->productDailyWinTimeRepository->create($input);

        return $this->sendResponse($productDailyWinTime->toArray(), 'Product Daily Win Time saved successfully');
    }

    /**
     * Display the specified ProductDailyWinTime.
     * GET|HEAD /productDailyWinTimes/{id}
     *
     * @param int $id
     *
     * @return Response
     */
    public function show($id)
    {
        /** @var ProductDailyWinTime $productDailyWinTime */
        $productDailyWinTime = $this->productDailyWinTimeRepository->find($id);

        if (empty($productDailyWinTime)) {
            return $this->sendError('Product Daily Win Time not found');
        }

        return $this->sendResponse($productDailyWinTime->toArray(), 'Product Daily Win Time retrieved successfully');
    }

    /**
     * Update the specified ProductDailyWinTime in storage.
     * PUT/PATCH /productDailyWinTimes/{id}
     *
     * @param int $id
     * @param UpdateProductDailyWinTimeAPIRequest $request
     *
     * @return Response
     */
    public function update($id, UpdateProductDailyWinTimeAPIRequest $request)
    {
        $input = $request->all();

        /** @var ProductDailyWinTime $productDailyWinTime */
        $productDailyWinTime = $this->productDailyWinTimeRepository->find($id);

        if (empty($productDailyWinTime)) {
            return $this->sendError('Product Daily Win Time not found');
        }

        $productDailyWinTime = $this->productDailyWinTimeRepository->update($input, $id);

        return $this->sendResponse($productDailyWinTime->toArray(), 'ProductDailyWinTime updated successfully');
    }

    /**
     * Remove the specified ProductDailyWinTime from storage.
     * DELETE /productDailyWinTimes/{id}
     *
     * @param int $id
     *
     * @throws \Exception
     *
     * @return Response
     */
    public function destroy($id)
    {
        /** @var ProductDailyWinTime $productDailyWinTime */
        $productDailyWinTime = $this->productDailyWinTimeRepository->find($id);

        if (empty($productDailyWinTime)) {
            return $this->sendError('Product Daily Win Time not found');
        }

        $productDailyWinTime->delete();

        return $this->sendSuccess('Product Daily Win Time deleted successfully');
    }
}
