<?php

namespace App\Http\Controllers\API;

use App\Http\Requests\API\CreateProductInPromoAPIRequest;
use App\Http\Requests\API\UpdateProductInPromoAPIRequest;
use App\Models\ProductInPromo;
use App\Repositories\ProductInPromoRepository;
use Illuminate\Http\Request;
use App\Http\Controllers\AppBaseController;
use Response;

/**
 * Class ProductInPromoController
 * @package App\Http\Controllers\API
 */

class ProductInPromoAPIController extends AppBaseController
{
    /** @var  ProductInPromoRepository */
    private $productInPromoRepository;

    public function __construct(ProductInPromoRepository $productInPromoRepo)
    {
        $this->productInPromoRepository = $productInPromoRepo;
    }

    /**
     * Display a listing of the ProductInPromo.
     * GET|HEAD /productInPromos
     *
     * @param Request $request
     * @return Response
     */
    public function index(Request $request)
    {
        $productInPromos = $this->productInPromoRepository->all(
            $request->except(['skip', 'limit']),
            $request->get('skip'),
            $request->get('limit')
        );

        return $this->sendResponse($productInPromos->toArray(), 'Product In Promos retrieved successfully');
    }

    /**
     * Store a newly created ProductInPromo in storage.
     * POST /productInPromos
     *
     * @param CreateProductInPromoAPIRequest $request
     *
     * @return Response
     */
    public function store(CreateProductInPromoAPIRequest $request)
    {
        $input = $request->all();

        $productInPromo = $this->productInPromoRepository->create($input);

        return $this->sendResponse($productInPromo->toArray(), 'Product In Promo saved successfully');
    }

    /**
     * Display the specified ProductInPromo.
     * GET|HEAD /productInPromos/{id}
     *
     * @param int $id
     *
     * @return Response
     */
    public function show($id)
    {
        /** @var ProductInPromo $productInPromo */
        $productInPromo = $this->productInPromoRepository->find($id);

        if (empty($productInPromo)) {
            return $this->sendError('Product In Promo not found');
        }

        return $this->sendResponse($productInPromo->toArray(), 'Product In Promo retrieved successfully');
    }

    /**
     * Update the specified ProductInPromo in storage.
     * PUT/PATCH /productInPromos/{id}
     *
     * @param int $id
     * @param UpdateProductInPromoAPIRequest $request
     *
     * @return Response
     */
    public function update($id, UpdateProductInPromoAPIRequest $request)
    {
        $input = $request->all();

        /** @var ProductInPromo $productInPromo */
        $productInPromo = $this->productInPromoRepository->find($id);

        if (empty($productInPromo)) {
            return $this->sendError('Product In Promo not found');
        }

        $productInPromo = $this->productInPromoRepository->update($input, $id);

        return $this->sendResponse($productInPromo->toArray(), 'ProductInPromo updated successfully');
    }

    /**
     * Remove the specified ProductInPromo from storage.
     * DELETE /productInPromos/{id}
     *
     * @param int $id
     *
     * @throws \Exception
     *
     * @return Response
     */
    public function destroy($id)
    {
        /** @var ProductInPromo $productInPromo */
        $productInPromo = $this->productInPromoRepository->find($id);

        if (empty($productInPromo)) {
            return $this->sendError('Product In Promo not found');
        }

        $productInPromo->delete();

        return $this->sendSuccess('Product In Promo deleted successfully');
    }
}
