<?php

namespace App\Http\Controllers\API;

use App\Http\Requests\API\CreateProductInPromoByDayAPIRequest;
use App\Http\Requests\API\UpdateProductInPromoByDayAPIRequest;
use App\Models\ProductInPromoByDay;
use App\Repositories\ProductInPromoByDayRepository;
use Illuminate\Http\Request;
use App\Http\Controllers\AppBaseController;
use Response;

/**
 * Class ProductInPromoByDayController
 * @package App\Http\Controllers\API
 */

class ProductInPromoByDayAPIController extends AppBaseController
{
    /** @var  ProductInPromoByDayRepository */
    private $productInPromoByDayRepository;

    public function __construct(ProductInPromoByDayRepository $productInPromoByDayRepo)
    {
        $this->productInPromoByDayRepository = $productInPromoByDayRepo;
    }

    /**
     * Display a listing of the ProductInPromoByDay.
     * GET|HEAD /productInPromoByDays
     *
     * @param Request $request
     * @return Response
     */
    public function index(Request $request)
    {
        $productInPromoByDays = $this->productInPromoByDayRepository->all(
            $request->except(['skip', 'limit']),
            $request->get('skip'),
            $request->get('limit')
        );

        return $this->sendResponse($productInPromoByDays->toArray(), 'Product In Promo By Days retrieved successfully');
    }

    /**
     * Store a newly created ProductInPromoByDay in storage.
     * POST /productInPromoByDays
     *
     * @param CreateProductInPromoByDayAPIRequest $request
     *
     * @return Response
     */
    public function store(CreateProductInPromoByDayAPIRequest $request)
    {
        $input = $request->all();

        $productInPromoByDay = $this->productInPromoByDayRepository->create($input);

        return $this->sendResponse($productInPromoByDay->toArray(), 'Product In Promo By Day saved successfully');
    }

    /**
     * Display the specified ProductInPromoByDay.
     * GET|HEAD /productInPromoByDays/{id}
     *
     * @param int $id
     *
     * @return Response
     */
    public function show($id)
    {
        /** @var ProductInPromoByDay $productInPromoByDay */
        $productInPromoByDay = $this->productInPromoByDayRepository->find($id);

        if (empty($productInPromoByDay)) {
            return $this->sendError('Product In Promo By Day not found');
        }

        return $this->sendResponse($productInPromoByDay->toArray(), 'Product In Promo By Day retrieved successfully');
    }

    /**
     * Update the specified ProductInPromoByDay in storage.
     * PUT/PATCH /productInPromoByDays/{id}
     *
     * @param int $id
     * @param UpdateProductInPromoByDayAPIRequest $request
     *
     * @return Response
     */
    public function update($id, UpdateProductInPromoByDayAPIRequest $request)
    {
        $input = $request->all();

        /** @var ProductInPromoByDay $productInPromoByDay */
        $productInPromoByDay = $this->productInPromoByDayRepository->find($id);

        if (empty($productInPromoByDay)) {
            return $this->sendError('Product In Promo By Day not found');
        }

        $productInPromoByDay = $this->productInPromoByDayRepository->update($input, $id);

        return $this->sendResponse($productInPromoByDay->toArray(), 'ProductInPromoByDay updated successfully');
    }

    /**
     * Remove the specified ProductInPromoByDay from storage.
     * DELETE /productInPromoByDays/{id}
     *
     * @param int $id
     *
     * @throws \Exception
     *
     * @return Response
     */
    public function destroy($id)
    {
        /** @var ProductInPromoByDay $productInPromoByDay */
        $productInPromoByDay = $this->productInPromoByDayRepository->find($id);

        if (empty($productInPromoByDay)) {
            return $this->sendError('Product In Promo By Day not found');
        }

        $productInPromoByDay->delete();

        return $this->sendSuccess('Product In Promo By Day deleted successfully');
    }
}
