<?php

namespace App\Http\Controllers;

use App\Http\Requests\CreateProductInPromoByDayRequest;
use App\Http\Requests\UpdateProductInPromoByDayRequest;
use App\Repositories\ProductInPromoByDayRepository;
use App\Http\Controllers\AppBaseController;
use Illuminate\Http\Request;
use Flash;
use Response;

class ProductInPromoByDayController extends AppBaseController
{
    /** @var  ProductInPromoByDayRepository */
    private $productInPromoByDayRepository;

    public function __construct(ProductInPromoByDayRepository $productInPromoByDayRepo)
    {
        $this->productInPromoByDayRepository = $productInPromoByDayRepo;
    }

    /**
     * Display a listing of the ProductInPromoByDay.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function index(Request $request)
    {
        $productInPromoByDays = $this->productInPromoByDayRepository->paginate(25);

        return view('product_in_promo_by_days.index')
            ->with('productInPromoByDays', $productInPromoByDays);
    }

    /**
     * Show the form for creating a new ProductInPromoByDay.
     *
     * @return Response
     */
    public function create()
    {
        return view('product_in_promo_by_days.create');
    }

    /**
     * Store a newly created ProductInPromoByDay in storage.
     *
     * @param CreateProductInPromoByDayRequest $request
     *
     * @return Response
     */
    public function store(CreateProductInPromoByDayRequest $request)
    {
        $input = $request->all();

        $productInPromoByDay = $this->productInPromoByDayRepository->create($input);

        Flash::success('Product In Promo By Day saved successfully.');

        return redirect(route('productInPromoByDays.index'));
    }

    /**
     * Display the specified ProductInPromoByDay.
     *
     * @param int $id
     *
     * @return Response
     */
    public function show($id)
    {
        $productInPromoByDay = $this->productInPromoByDayRepository->find($id);

        if (empty($productInPromoByDay)) {
            Flash::error('Product In Promo By Day not found');

            return redirect(route('productInPromoByDays.index'));
        }

        return view('product_in_promo_by_days.show')->with('productInPromoByDay', $productInPromoByDay);
    }

    /**
     * Show the form for editing the specified ProductInPromoByDay.
     *
     * @param int $id
     *
     * @return Response
     */
    public function edit($id)
    {
        $productInPromoByDay = $this->productInPromoByDayRepository->find($id);

        if (empty($productInPromoByDay)) {
            Flash::error('Product In Promo By Day not found');

            return redirect(route('productInPromoByDays.index'));
        }

        return view('product_in_promo_by_days.edit')->with('productInPromoByDay', $productInPromoByDay);
    }

    /**
     * Update the specified ProductInPromoByDay in storage.
     *
     * @param int $id
     * @param UpdateProductInPromoByDayRequest $request
     *
     * @return Response
     */
    public function update($id, UpdateProductInPromoByDayRequest $request)
    {
        $productInPromoByDay = $this->productInPromoByDayRepository->find($id);

        if (empty($productInPromoByDay)) {
            Flash::error('Product In Promo By Day not found');

            return redirect(route('productInPromoByDays.index'));
        }

        $productInPromoByDay = $this->productInPromoByDayRepository->update($request->all(), $id);

        Flash::success('Product In Promo By Day updated successfully.');

        return redirect(route('productInPromoByDays.index'));
    }

    /**
     * Remove the specified ProductInPromoByDay from storage.
     *
     * @param int $id
     *
     * @throws \Exception
     *
     * @return Response
     */
    public function destroy($id)
    {
        $productInPromoByDay = $this->productInPromoByDayRepository->find($id);

        if (empty($productInPromoByDay)) {
            Flash::error('Product In Promo By Day not found');

            return redirect(route('productInPromoByDays.index'));
        }

        $this->productInPromoByDayRepository->delete($id);

        Flash::success('Product In Promo By Day deleted successfully.');

        return redirect(route('productInPromoByDays.index'));
    }
}
