<?php namespace Tests\APIs;

use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseTransactions;
use Tests\TestCase;
use Tests\ApiTestTrait;
use App\Models\ProductDailyWinTime;

class ProductDailyWinTimeApiTest extends TestCase
{
    use ApiTestTrait, WithoutMiddleware, DatabaseTransactions;

    /**
     * @test
     */
    public function test_create_product_daily_win_time()
    {
        $productDailyWinTime = ProductDailyWinTime::factory()->make()->toArray();

        $this->response = $this->json(
            'POST',
            '/api/product_daily_win_times', $productDailyWinTime
        );

        $this->assertApiResponse($productDailyWinTime);
    }

    /**
     * @test
     */
    public function test_read_product_daily_win_time()
    {
        $productDailyWinTime = ProductDailyWinTime::factory()->create();

        $this->response = $this->json(
            'GET',
            '/api/product_daily_win_times/'.$productDailyWinTime->id
        );

        $this->assertApiResponse($productDailyWinTime->toArray());
    }

    /**
     * @test
     */
    public function test_update_product_daily_win_time()
    {
        $productDailyWinTime = ProductDailyWinTime::factory()->create();
        $editedProductDailyWinTime = ProductDailyWinTime::factory()->make()->toArray();

        $this->response = $this->json(
            'PUT',
            '/api/product_daily_win_times/'.$productDailyWinTime->id,
            $editedProductDailyWinTime
        );

        $this->assertApiResponse($editedProductDailyWinTime);
    }

    /**
     * @test
     */
    public function test_delete_product_daily_win_time()
    {
        $productDailyWinTime = ProductDailyWinTime::factory()->create();

        $this->response = $this->json(
            'DELETE',
             '/api/product_daily_win_times/'.$productDailyWinTime->id
         );

        $this->assertApiSuccess();
        $this->response = $this->json(
            'GET',
            '/api/product_daily_win_times/'.$productDailyWinTime->id
        );

        $this->response->assertStatus(404);
    }
}
