<?php namespace Tests\Repositories;

use App\Models\ProductDailyWinTime;
use App\Repositories\ProductDailyWinTimeRepository;
use Illuminate\Foundation\Testing\DatabaseTransactions;
use Tests\TestCase;
use Tests\ApiTestTrait;

class ProductDailyWinTimeRepositoryTest extends TestCase
{
    use ApiTestTrait, DatabaseTransactions;

    /**
     * @var ProductDailyWinTimeRepository
     */
    protected $productDailyWinTimeRepo;

    public function setUp() : void
    {
        parent::setUp();
        $this->productDailyWinTimeRepo = \App::make(ProductDailyWinTimeRepository::class);
    }

    /**
     * @test create
     */
    public function test_create_product_daily_win_time()
    {
        $productDailyWinTime = ProductDailyWinTime::factory()->make()->toArray();

        $createdProductDailyWinTime = $this->productDailyWinTimeRepo->create($productDailyWinTime);

        $createdProductDailyWinTime = $createdProductDailyWinTime->toArray();
        $this->assertArrayHasKey('id', $createdProductDailyWinTime);
        $this->assertNotNull($createdProductDailyWinTime['id'], 'Created ProductDailyWinTime must have id specified');
        $this->assertNotNull(ProductDailyWinTime::find($createdProductDailyWinTime['id']), 'ProductDailyWinTime with given id must be in DB');
        $this->assertModelData($productDailyWinTime, $createdProductDailyWinTime);
    }

    /**
     * @test read
     */
    public function test_read_product_daily_win_time()
    {
        $productDailyWinTime = ProductDailyWinTime::factory()->create();

        $dbProductDailyWinTime = $this->productDailyWinTimeRepo->find($productDailyWinTime->id);

        $dbProductDailyWinTime = $dbProductDailyWinTime->toArray();
        $this->assertModelData($productDailyWinTime->toArray(), $dbProductDailyWinTime);
    }

    /**
     * @test update
     */
    public function test_update_product_daily_win_time()
    {
        $productDailyWinTime = ProductDailyWinTime::factory()->create();
        $fakeProductDailyWinTime = ProductDailyWinTime::factory()->make()->toArray();

        $updatedProductDailyWinTime = $this->productDailyWinTimeRepo->update($fakeProductDailyWinTime, $productDailyWinTime->id);

        $this->assertModelData($fakeProductDailyWinTime, $updatedProductDailyWinTime->toArray());
        $dbProductDailyWinTime = $this->productDailyWinTimeRepo->find($productDailyWinTime->id);
        $this->assertModelData($fakeProductDailyWinTime, $dbProductDailyWinTime->toArray());
    }

    /**
     * @test delete
     */
    public function test_delete_product_daily_win_time()
    {
        $productDailyWinTime = ProductDailyWinTime::factory()->create();

        $resp = $this->productDailyWinTimeRepo->delete($productDailyWinTime->id);

        $this->assertTrue($resp);
        $this->assertNull(ProductDailyWinTime::find($productDailyWinTime->id), 'ProductDailyWinTime should not exist in DB');
    }
}
