<?php namespace Tests\Repositories;

use App\Models\ProductInPromo;
use App\Repositories\ProductInPromoRepository;
use Illuminate\Foundation\Testing\DatabaseTransactions;
use Tests\TestCase;
use Tests\ApiTestTrait;

class ProductInPromoRepositoryTest extends TestCase
{
    use ApiTestTrait, DatabaseTransactions;

    /**
     * @var ProductInPromoRepository
     */
    protected $productInPromoRepo;

    public function setUp() : void
    {
        parent::setUp();
        $this->productInPromoRepo = \App::make(ProductInPromoRepository::class);
    }

    /**
     * @test create
     */
    public function test_create_product_in_promo()
    {
        $productInPromo = ProductInPromo::factory()->make()->toArray();

        $createdProductInPromo = $this->productInPromoRepo->create($productInPromo);

        $createdProductInPromo = $createdProductInPromo->toArray();
        $this->assertArrayHasKey('id', $createdProductInPromo);
        $this->assertNotNull($createdProductInPromo['id'], 'Created ProductInPromo must have id specified');
        $this->assertNotNull(ProductInPromo::find($createdProductInPromo['id']), 'ProductInPromo with given id must be in DB');
        $this->assertModelData($productInPromo, $createdProductInPromo);
    }

    /**
     * @test read
     */
    public function test_read_product_in_promo()
    {
        $productInPromo = ProductInPromo::factory()->create();

        $dbProductInPromo = $this->productInPromoRepo->find($productInPromo->id);

        $dbProductInPromo = $dbProductInPromo->toArray();
        $this->assertModelData($productInPromo->toArray(), $dbProductInPromo);
    }

    /**
     * @test update
     */
    public function test_update_product_in_promo()
    {
        $productInPromo = ProductInPromo::factory()->create();
        $fakeProductInPromo = ProductInPromo::factory()->make()->toArray();

        $updatedProductInPromo = $this->productInPromoRepo->update($fakeProductInPromo, $productInPromo->id);

        $this->assertModelData($fakeProductInPromo, $updatedProductInPromo->toArray());
        $dbProductInPromo = $this->productInPromoRepo->find($productInPromo->id);
        $this->assertModelData($fakeProductInPromo, $dbProductInPromo->toArray());
    }

    /**
     * @test delete
     */
    public function test_delete_product_in_promo()
    {
        $productInPromo = ProductInPromo::factory()->create();

        $resp = $this->productInPromoRepo->delete($productInPromo->id);

        $this->assertTrue($resp);
        $this->assertNull(ProductInPromo::find($productInPromo->id), 'ProductInPromo should not exist in DB');
    }
}
